/**
 * @import {Element} from 'hast'
 * @import {Paragraph} from 'mdast'
 * @import {State} from '../state.js'
 */
/**
 * Turn an mdast `paragraph` node into hast.
 *
 * @param {State} state
 *   Info passed around.
 * @param {Paragraph} node
 *   mdast node.
 * @returns {Element}
 *   hast node.
 */
export function paragraph(state: State, node: Paragraph): Element;
import type { State } from '../state.js';
import type { Paragraph } from 'mdast';
import type { Element } from 'hast';
//# sourceMappingURL=paragraph.d.ts.map