module.exports={A:{A:{"2":"F A B zC","8":"K D E"},B:{"2":"C L M G N O P","8":"Q H R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p q r","1025":"0 1 2 3 4 5 6 7 8 s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB I"},C:{"1":"0 1 2 3 4 5 6 7 8 9 J bB K D E F A B C L M G N O P cB AB BB CB DB EB FB GB HB IB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B WC 6B XC 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC Q H R YC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB I ZC aC OC 1C 2C 3C","129":"0C VC 4C 5C"},D:{"1":"DB","8":"9 J bB K D E F A B C L M G N O P cB AB BB CB EB FB GB HB IB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B WC 6B XC 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC Q H R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p q r","1025":"0 1 2 3 4 5 6 7 8 s t u v w x y z JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB ZB aB I ZC aC OC"},E:{"1":"A B C L M G cC PC QC BD CD DD dC eC RC ED SC fC gC hC iC jC FD TC kC lC mC nC oC GD UC pC qC rC sC HD tC uC vC wC ID","260":"J bB K D E F 6C bC 7C 8C 9C AD"},F:{"2":"F","8":"9 G N O P cB AB BB CB DB EB FB GB HB IB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC NC Q H R YC","584":"S T U V W X Y Z a b c d","1025":"0 1 2 3 4 5 6 7 8 e f g h i j k l m n o p q r s t u v w x y z","2052":"B C JD KD LD MD PC xC ND QC"},G:{"1":"E PD QD RD SD TD UD VD WD XD YD ZD aD bD cD dD eD fD gD hD dC eC RC iD SC fC gC hC iC jC jD TC kC lC mC nC oC kD UC pC qC rC sC lD tC uC vC wC","8":"bC OD yC"},H:{"8":"mD"},I:{"8":"VC J nD oD pD qD yC rD sD","1025":"I"},J:{"1":"A","8":"D"},K:{"8":"A B C PC xC QC","1025":"H"},L:{"1025":"I"},M:{"1":"OC"},N:{"2":"A B"},O:{"8":"RC"},P:{"1":"AB BB CB DB EB FB GB HB IB","8":"9 J tD uD vD wD xD cC yD zD 0D 1D 2D SC TC UC 3D"},Q:{"8":"4D"},R:{"8":"5D"},S:{"1":"6D 7D"}},B:2,C:"MathML",D:true};
