"""API route modules."""

from cachibot.api.routes import (
    auth,
    chat,
    config,
    creation,
    health,
    knowledge,
    models,
    plugins,
    providers,
    update,
    work,
)

__all__ = [
    "auth",
    "chat",
    "config",
    "creation",
    "health",
    "knowledge",
    "models",
    "plugins",
    "providers",
    "update",
    "work",
]
